@@ -114,14 +114,15 @@ def cancel_subscription_confirm(request, token):
         raise Http404
 
     try:
-        obj = Subscription.objects.get(pk=data['id'], is_active=True)
+        obj = Subscription.objects.get(pk=data['id'])
     except Subscription.DoesNotExist:
         raise Http404
 
     cfg = apps.get_app_config('stripe_subscription')
     template = cfg.get_template(request.get_host(), 'cancel-success')
     context = {
-        'is_ok': utils.cancel_subscription(obj)
+        'is_ok': utils.cancel_subscription(obj) if obj.is_active else True,
+        'host': obj.site.domain
     }
 
     return render(request, template, context)
